@@ -1,10 +1,10 @@
 
 # -*-Fundamental-*- 
-require 5;    # Time-stamp: "2001-03-18 00:36:10 MST"
+require 5;    # Time-stamp: "2004-03-24 14:50:00 AST"
 package Sort::ArbBiLex;
 use strict;
 use vars qw(@ISA $Debug $VERSION);
-$VERSION = 3.40;
+$VERSION = 3.41;
 $Debug = 0;
 use Carp;
 use integer; # vroom vroom
@@ -333,7 +333,7 @@ __END__
 
 =head1 NAME
 
-Sort::ArbBiLex -- make sort functions for arbitrary sort orders
+Sort::ArbBiLex - make sort functions for arbitrary sort orders
 
 =head1 SYNOPSIS
 
@@ -804,6 +804,46 @@ always, though, don't try optimizing unless you're sure you need to
 (and don't be surprised if it doesn't have as great an effect as you
 hoped for).
 
+=head1 A GOOD STARTING POINT
+
+Here's a declaration for a sort function that uses all the characters
+A-Z / a-z and also all the alphabetic characters in Latin-1.  It
+should be a a good starting point for most declarations you'd want:
+
+  use Sort::ArbBiLex (
+    'schmancy_sort' =>
+    "
+     a A              
+     b B
+     c C  
+     d D  
+     e E        
+     f F
+     g G
+     h H
+     i I        
+     j J
+     k K
+     l L
+     m M
+     n N  
+     o O            
+     p P
+     q Q
+     r R
+     s S 
+     t T  
+     u U        
+     v V
+     w W
+     x X
+     y Y   
+     z Z
+    "
+  );
+
+Edit and re-shuffle letters as necessary.
+
 =head1 GUTS
 
 * ArbBiLex stands for "arbitrary bi-level lexicographic".
